==> xpdf-0.92.tar.gz: xpdf-0.92/xpdf/SFont.cc <==
//========================================================================
//
// SFont.cc
//
//========================================================================

#ifdef __GNUC__
#pragma implementation
#endif

#include "SFont.h"

//------------------------------------------------------------------------

SFontEngine::SFontEngine(Display *display, Visual *visual, int depth,
			 Colormap colormap) {
  this->display = display;
  this->visual = visual;
  this->depth = depth;
  this->colormap = colormap;
};

SFontEngine::~SFontEngine() {
}

void SFontEngine::useTrueColor(int rMax, int rShift, int gMax, int gShift,
			       int bMax, int bShift) {
  trueColor = gTrue;
  this->rMax = rMax;
  this->rShift = rShift;
  this->gMax = gMax;
  this->gShift = gShift;
  this->bMax = bMax;
  this->bShift = bShift;
}

void SFontEngine::useColorCube(Gulong *colors, int nRGB) {
  trueColor = gFalse;
  this->colors = colors;
  this->nRGB = nRGB;
  rMax = gMax = bMax = nRGB - 1;
}

Gulong SFontEngine::findColor(int r, int g, int b) {
  int r1, g1, b1;
  Gulong pix;

  r1 = ((r & 0xffff) * rMax) / 0xffff;
  g1 = ((g & 0xffff) * gMax) / 0xffff;
  b1 = ((b & 0xffff) * bMax) / 0xffff;
  if (trueColor) {
    pix = (r1 << rShift) + (g1 << gShift) + (b1 << bShift);
  } else {
    pix = colors[(r1 * nRGB + g1) * nRGB + b1];
  }
  return pix;
}

//------------------------------------------------------------------------

SFontFile::SFontFile() {
}

SFontFile::~SFontFile() {
}

//------------------------------------------------------------------------

SFont::SFont() {
}

SFont::~SFont() {
}

==> xpdf-1.00.tar.gz: xpdf-1.00/xpdf/SFont.cc <==
//========================================================================
//
// SFont.cc
//
//========================================================================

#ifdef __GNUC__
#pragma implementation
#endif

#include <aconf.h>
#include "SFont.h"

//------------------------------------------------------------------------

SFontEngine::SFontEngine(Display *displayA, Visual *visualA, int depthA,
			 Colormap colormapA) {
  display = displayA;
  visual = visualA;
  depth = depthA;
  colormap = colormapA;
}

SFontEngine::~SFontEngine() {
}

void SFontEngine::useTrueColor(int rMaxA, int rShiftA, int gMaxA, int gShiftA,
			       int bMaxA, int bShiftA) {
  trueColor = gTrue;
  rMax = rMaxA;
  rShift = rShiftA;
  gMax = gMaxA;
  gShift = gShiftA;
  bMax = bMaxA;
  bShift = bShiftA;
}

void SFontEngine::useColorCube(Gulong *colorsA, int nRGBA) {
  trueColor = gFalse;
  colors = colorsA;
  nRGB = nRGBA;
  rMax = gMax = bMax = nRGB - 1;
}

Gulong SFontEngine::findColor(int r, int g, int b) {
  int r1, g1, b1;
  Gulong pix;

  r1 = ((r & 0xffff) * rMax) / 0xffff;
  g1 = ((g & 0xffff) * gMax) / 0xffff;
  b1 = ((b & 0xffff) * bMax) / 0xffff;
  if (trueColor) {
    pix = (r1 << rShift) + (g1 << gShift) + (b1 << bShift);
  } else {
    pix = colors[(r1 * nRGB + g1) * nRGB + b1];
  }
  return pix;
}

//------------------------------------------------------------------------

SFontFile::SFontFile() {
}

SFontFile::~SFontFile() {
}

//------------------------------------------------------------------------

SFont::SFont() {
}

SFont::~SFont() {
}
